"""
NexusController - Advanced Android Automation Platform

NexusController is a comprehensive and professional-grade Android device automation platform
that bridges the gap between manual testing and continuous integration. It provides a unified
solution for Android device control, UI automation, and test orchestration with Model Context
Protocol (MCP) support.

This package provides:
- Device management and control via ADB
- UI automation through Maestro integration
- Screen recording and screenshot capabilities
- App installation and management
- Interactive CLI and Jupyter notebook interfaces
- MCP server implementation for AI assistant integration

Created and maintained by ankit1057 (github.com/ankit1057)
"""

__version__ = "0.1.2"
__author__ = "ankit1057"
__license__ = "MIT with Commercial Use Clause"

from .controller import AndroidController
from .config import CONSTANTS

# Import MCP server functions
try:
    from .mcp import start_server, run
except ImportError:
    # MCP module is optional
    pass 